@@ -3,6 +3,8 @@
 # gets called at the start of plotmo and plotres
 plotmo.prolog <- function(object, object.name, trace, ...)
 {
+    trace2(trace, "--plotmo_prolog for %s object %s\n",
+           class(object)[1], object.name)
     UseMethod("plotmo.prolog")
 }
 plotmo.prolog.default <- function(object, object.name, ...)
