@@ -1,5 +1,6 @@
-# test.non.earth.R: test plotmo on non-earth models
-# Stephen Milborrow, Basley KwaZulu-Natal Mar 2011
+# test.caret.R: test plotmo on caret models
+#
+# TODO This is a minimal set of tests.
 
 library(plotmo)
 library(earth)
@@ -18,19 +19,26 @@ dopar <- function(nrows, ncols, caption = "")
     par(mgp = c(1.6, 0.6, 0))
     par(cex = 0.7)
 }
-expect.err <- function(obj) # test that we got an error as expected from a try() call
+# test that we got an error as expected from a try() call
+expect.err <- function(object, expected.msg="")
 {
-    if(class(obj)[1] == "try-error")
-        cat("Got error as expected\n")
-    else
-        stop("did not get expected error")
+    if(class(object)[1] == "try-error") {
+        msg <- attr(object, "condition")$message[1]
+        if(length(grep(expected.msg, msg, fixed=TRUE)))
+            cat("Got error as expected from ",
+                deparse(substitute(object)), "\n", sep="")
+        else
+            stop(sprintf("Expected: %s\n  Got:      %s",
+                         expected.msg, substr(msg[1], 1, 1000)))
+    } else
+        stop("Did not get expected error: ", expected.msg)
 }
 library(caret)
 set.seed(2015)
 caret.earth.mod <- train(O3~., data=ozone1, method="earth",
                          tuneGrid=data.frame(degree=2, nprune=10))
+# SHOWCALL is just a testing thing, so we can see who created the plot on the plot itself
 plotmo(caret.earth.mod, trace=1, SHOWCALL=TRUE)
-# but the pairs are plotted here
 plotmo(caret.earth.mod$finalModel, trace=1, SHOWCALL=TRUE)
 plotres(caret.earth.mod, trace=1, SHOWCALL=TRUE)
 # plotres(caret.earth.mod$finalModel, trace=1, SHOWCALL=TRUE)
@@ -58,7 +66,7 @@ set.seed(2015)
 etit <- etitanic
 etit$survived <- factor(ifelse(etit$survived == 1, "yes", "no"),
                        levels = c("yes", "no"))
-# TODO pairs are not plotted
+# TODO pairs are not automatically plotted
 caret.earth.mod2 <- train(survived ~ .,
             data = etit,
             method = "earth",
