@@ -17,13 +17,13 @@ expect.err <- function(object, expected.msg="")
     if(class(object)[1] == "try-error") {
         msg <- attr(object, "condition")$message[1]
         if(length(grep(expected.msg, msg, fixed=TRUE)))
-            cat0("Got error as expected from ",
-                deparse(substitute(object)), "\n")
+            cat("Got error as expected from ",
+                deparse(substitute(object)), "\n", sep="")
         else
             stop(sprintf("Expected: %s\n  Got:      %s",
-                         expected.msg, substr(msg, 1, 1000)))
+                         expected.msg, substr(msg[1], 1, 1000)))
     } else
-        stop("did not get expected error ", expected.msg)
+        stop("Did not get expected error: ", expected.msg)
 }
 cat0("=== test callers.name\n")
 
